@@ -198,6 +198,14 @@ bool archive_write( const uint8_t * const buf, const int size )
   }
 
 
+void init_tar_header( Tar_header header )	// set magic and version
+  {
+  std::memset( header, 0, header_size );
+  std::memcpy( header + magic_o, ustar_magic, magic_l - 1 );
+  header[version_o] = header[version_o+1] = '0';
+  }
+
+
 unsigned char xdigit( const unsigned value )
   {
   if( value <= 9 ) return '0' + value;
@@ -231,7 +239,7 @@ unsigned long long record_size( const unsigned keyword_size,
   return decimal_digits( d1 + size ) + size;
   }
 
-bool write_extended( const Extended & extended, const Tar_header uheader )
+bool write_extended( const Extended & extended )
   {
   const int path_rec = extended.path.size() ?
                        record_size( 4, extended.path.size() ) : 0;
@@ -241,6 +249,7 @@ bool write_extended( const Extended & extended, const Tar_header uheader )
                        record_size( 4, decimal_digits( extended.size ) ) : 0;
   const unsigned long long edsize = path_rec + lpath_rec + size_rec + 22;
   const unsigned long long bufsize = round_up( edsize );
+  if( edsize >= 1ULL << 33 ) return false;	// too much extended data
   if( bufsize == 0 ) return edsize == 0;	// overflow or no extended data
   char * const buf = new char[bufsize+1];	// extended records buffer
   unsigned long long pos = path_rec;		// goto can't cross this
@@ -262,8 +271,8 @@ bool write_extended( const Extended & extended, const Tar_header uheader )
              crc32c.windowed_crc( (const uint8_t *)buf, edsize - 9, edsize ) );
   std::memset( buf + edsize, 0, bufsize - edsize );	// wipe padding
   Tar_header header;				// extended header
-  std::memcpy( header, uheader, header_size );	// copy from ustar header
-  header[typeflag_o] = tf_extended;		// then modify some fields
+  init_tar_header( header );
+  header[typeflag_o] = tf_extended;		// fill only required fields
   print_octal( header + size_o, size_l - 1, edsize );
   print_octal( header + chksum_o, chksum_l - 1,
                ustar_chksum( (const uint8_t *)header ) );
@@ -307,12 +316,15 @@ const char * remove_leading_dotdot( const char * const filename )
   }
 
 
+// Return true if filename fits in the ustar header.
 bool store_name( const char * const filename, Extended & extended,
                  Tar_header header )
   {
   const char * const stored_name = remove_leading_dotdot( filename );
   const int len = std::strlen( stored_name );
   enum { max_len = prefix_l + 1 + name_l };	// prefix + '/' + name
+
+  // first try storing filename in the ustar header
   if( len <= name_l )				// stored_name fits in name
     { std::memcpy( header + name_o, stored_name, len ); return true; }
   if( len <= max_len )				// find shortest prefix
@@ -323,9 +335,8 @@ bool store_name( const char * const filename, Extended & extended,
         std::memcpy( header + prefix_o, stored_name, i );
         return true;
         }
-  // store full name in extended record, truncated name in ustar header
+  // store filename in extended record, leave name zeroed in ustar header
   extended.path = stored_name;
-  std::strncpy( header + name_o, stored_name, name_l );
   return false;
   }
 
@@ -342,7 +353,7 @@ int add_member( const char * const filename, const struct stat *,
       return 0; }
   Extended extended;		// metadata for extended records
   Tar_header header;
-  std::memset( header, 0, header_size );
+  init_tar_header( header );
   store_name( filename, extended, header );
 
   const mode_t mode = st.st_mode;
@@ -374,17 +385,19 @@ int add_member( const char * const filename, const struct stat *,
   else if( S_ISLNK( mode ) )
     {
     typeflag = tf_symlink;
-    if( st.st_size > linkname_l ||
-        readlink( filename, header + linkname_o, linkname_l ) != st.st_size )
+    long len;
+    if( st.st_size <= linkname_l )
+      len = readlink( filename, header + linkname_o, linkname_l );
+    else
       {
       char * const buf = new char[st.st_size+1];
-      const long len = readlink( filename, buf, st.st_size );
+      len = readlink( filename, buf, st.st_size );
       if( len == st.st_size ) { buf[len] = 0; extended.linkpath = buf; }
       delete[] buf;
-      if( len != st.st_size )
+      }
+    if( len != st.st_size )
       { show_file_error( filename, "Error reading link", (len < 0) ? errno : 0 );
         gretval = 1; return 0; }
-      }
     }
   else if( S_ISCHR( mode ) || S_ISBLK( mode ) )
     {
@@ -399,8 +412,6 @@ int add_member( const char * const filename, const struct stat *,
   else { show_file_error( filename, "Unknown file type." );
          gretval = 2; return 0; }
   header[typeflag_o] = typeflag;
-  std::memcpy( header + magic_o, ustar_magic, magic_l - 1 );
-  header[version_o] = header[version_o+1] = '0';
   const struct passwd * const pw = getpwuid( uid );
   if( pw && pw->pw_name )
     std::strncpy( header + uname_o, pw->pw_name, uname_l - 1 );
@@ -414,7 +425,7 @@ int add_member( const char * const filename, const struct stat *,
 
   const int infd = file_size ? open_instream( filename ) : -1;
   if( file_size && infd < 0 ) { gretval = 1; return 0; }
-  if( !extended.empty() && !write_extended( extended, header ) )
+  if( !extended.empty() && !write_extended( extended ) )
     { show_error( "Error writing extended header", errno ); return 1; }
   if( !archive_write( (const uint8_t *)header, header_size ) )
     { show_error( "Error writing ustar header", errno ); return 1; }
