@@ -121,7 +121,10 @@ int archive_read( const int infd, uint8_t * const buf, const int size,
     if( !islz && !istar && !iseof )		// corrupt or invalid format
       {
       show_error( "This does not look like a POSIX tar archive." );
-      if( has_lz_ext ) islz = true; else return 1;
+      if( has_lz_ext ) islz = true;
+      if( verbosity >= 2 && !islz && rd == size )
+        std::fprintf( stderr, "ustar chksum = %07o\n", ustar_chksum( buf ) );
+      if( !islz ) return 1;
       }
     if( !islz )						// uncompressed
       { if( rd == size ) return 0; fatal = true; return 2; }
@@ -421,6 +424,7 @@ int extract_member( const int infd, const Extended & extended,
   }
 
 
+// Removes any amount of leading "./" and '/' strings.
 const char * remove_leading_slash( const char * const filename )
   {
   static bool first_post = true;
@@ -609,10 +613,14 @@ int decode( const std::string & archive_name, const Arg_parser & parser,
     bool skip = filenames > 0;
     if( skip )
       for( int i = 0; i < parser.arguments(); ++i )
-        if( parser.code( i ) == 0 &&
-            ( compare_prefix_dir( parser.argument( i ).c_str(), filename ) ||
-              compare_tslash( filename, parser.argument( i ).c_str() ) ) )
-          { skip = false; name_pending[i] = false; break; }
+        if( parser.code( i ) == 0 )
+          {
+          const char * const name =
+            remove_leading_slash( parser.argument( i ).c_str() );
+          if( compare_prefix_dir( name, filename ) ||
+              compare_tslash( name, filename ) )
+            { skip = false; name_pending[i] = false; break; }
+          }
 
     if( extended.size == 0 &&
         ( typeflag == tf_regular || typeflag == tf_hiperf ) )
