@@ -57,7 +57,6 @@ int verbosity = 0;
 
 namespace {
 
-const char * const Program_name = "Tarlz";
 const char * const program_name = "tarlz";
 const char * const program_year = "2018";
 const char * invocation_name = 0;
@@ -67,8 +66,20 @@ enum Mode { m_none, m_append, m_concatenate, m_create, m_extract, m_list };
 
 void show_help()
   {
-  std::printf( "%s - Archiver with multimember lzip compression.\n", Program_name );
-  std::printf( "\nUsage: %s [options] [files]\n", invocation_name );
+  std::printf( "Tarlz is a small and simple implementation of the tar archiver. By default\n"
+               "tarlz creates, lists and extracts archives in a simplified posix pax format\n"
+               "compressed with lzip on a per file basis. Each tar member is compressed in\n"
+               "its own lzip member, as well as the end-of-file blocks. This method is fully\n"
+               "backward compatible with standard tar tools like GNU tar, which treat the\n"
+               "resulting multimember tar.lz archive like any other tar.lz archive. Tarlz\n"
+               "can append files to the end of such compressed archives.\n"
+               "\nThe tarlz file format is a safe posix-style backup format. In case of\n"
+               "corruption, tarlz can extract all the undamaged members from the tar.lz\n"
+               "archive, skipping over the damaged members, just like the standard\n"
+               "(uncompressed) tar. Moreover, the option '--keep-damaged' can be used to\n"
+               "recover as much data as possible from each damaged member, and lziprecover\n"
+               "can be used to recover some of the damaged members.\n"
+               "\nUsage: %s [options] [files]\n", invocation_name );
   std::printf( "\nOptions:\n"
                "  -h, --help                 display this help and exit\n"
                "  -V, --version              output version information and exit\n"
@@ -86,12 +97,13 @@ void show_help()
                "      --dsolid               create per-directory compressed archive\n"
                "      --no-solid             create per-file compressed archive (default)\n"
                "      --solid                create solidly compressed archive\n"
-               "      --group=<group>        use <group> name/ID for files added\n"
+               "      --anonymous            equivalent to '--owner=root --group=root'\n"
                "      --owner=<owner>        use <owner> name/ID for files added\n"
+               "      --group=<group>        use <group> name/ID for files added\n"
                "      --keep-damaged         don't delete partially extracted files\n"
                "      --missing-crc          exit with error status if missing extended CRC\n"
 //               "      --permissive           allow repeated extended headers and records\n"
-               "      --uncompressed         don't compress the created archive\n"
+               "      --uncompressed         don't compress the archive created\n"
                "\nExit status: 0 for a normal exit, 1 for environmental problems (file\n"
                "not found, invalid flags, I/O errors, etc), 2 to indicate a corrupt or\n"
                "invalid input file, 3 for an internal consistency error (eg, bug) which\n"
@@ -296,8 +308,8 @@ int main( const int argc, const char * const argv[] )
     { show_error( "Bad library version. At least lzlib 1.0 is required." );
       return 1; }
 
-  enum { opt_aso = 256, opt_crc, opt_dso, opt_grp, opt_kd, opt_nso, opt_own,
-         opt_per, opt_sol, opt_un };
+  enum { opt_ano = 256, opt_aso, opt_crc, opt_dso, opt_grp, opt_kd, opt_nso,
+         opt_own, opt_per, opt_sol, opt_un };
   const Arg_parser::Option options[] =
     {
     { '0',  0,                 Arg_parser::no  },
@@ -322,6 +334,7 @@ int main( const int argc, const char * const argv[] )
     { 'v', "verbose",          Arg_parser::no  },
     { 'V', "version",          Arg_parser::no  },
     { 'x', "extract",          Arg_parser::no  },
+    { opt_ano, "anonymous",    Arg_parser::no  },
     { opt_aso, "asolid",       Arg_parser::no  },
     { opt_dso, "dsolid",       Arg_parser::no  },
     { opt_grp, "group",        Arg_parser::yes },
@@ -362,6 +375,7 @@ int main( const int argc, const char * const argv[] )
       case 'v': if( verbosity < 4 ) ++verbosity; break;
       case 'V': show_version(); return 0;
       case 'x': set_mode( program_mode, m_extract ); break;
+      case opt_ano: set_owner( "root" ); set_group( "root" ); break;
       case opt_aso: cl_solid = 2; break;
       case opt_crc: missing_crc = true; break;
       case opt_dso: cl_solid = 1; break;
