@@ -37,6 +37,7 @@ inbad2="${testdir}"/test_bad2.txt
 test3="${testdir}"/test3.tar
 test3_lz="${testdir}"/test3.tar.lz
 test3dir_lz="${testdir}"/test3_dir.tar.lz
+test3dot_lz="${testdir}"/test3_dot.tar.lz
 t155="${testdir}"/t155.tar
 t155_lz="${testdir}"/t155.tar.lz
 tlzit1="${testdir}"/tlz_in_tar1.tar
@@ -65,7 +66,8 @@ lzlib_1_11() { [ ${lwarn} = 0 ] &&
 # test_bad1.tar.lz:  truncated at offset 6000 (of 7495)
 # test_bad2.tar.lz:  byte at offset 6000 changed from 0x56 to 0x46
 # test3.tar:         3 members (foo bar baz) + 2 zeroed 512-byte blocks
-# test3_dir.tar.lz:  like test3.tar.lz but members dir/foo dir/bar dir/baz
+# test3_dir.tar.lz:  like test3.tar.lz but members /dir/foo /dir/bar /dir/baz
+# test3_dot.tar.lz:  like test3.tar.lz but members ./foo ./bar ./baz
 # test3_bad1.tar:    byte at offset  259 changed from 't' to '0' (magic)
 # test3_bad2.tar:    byte at offset 1283 changed from 't' to '0' (magic)
 # test3_bad3.tar:    byte at offset 2559 changed from 0x00 to 0x20 (padding)
@@ -80,6 +82,7 @@ lzlib_1_11() { [ ${lwarn} = 0 ] &&
 # test3_bad6.tar.lz: 510 zeros prepended to test3.tar.lz (header in two blocks)
 # tlz_in_tar1.tar:   1 member (test3.tar.lz) first magic damaged
 # tlz_in_tar2.tar:   2 members (foo test3.tar.lz) first magic damaged
+# ug32chars.tar.lz:  1 member (foo) with 32-character owner and group names
 
 printf "testing tarlz-%s..." "$2"
 
@@ -162,16 +165,36 @@ cmp cfoo foo || test_failed $LINENO
 cmp cbar bar || test_failed $LINENO
 cmp cbaz baz || test_failed $LINENO
 rm -f foo bar baz || framework_failure
+"${TARLZ}" -q -xf "${test3_lz}" ./foo ./bar ./baz || test_failed $LINENO
+cmp cfoo foo || test_failed $LINENO
+cmp cbar bar || test_failed $LINENO
+cmp cbaz baz || test_failed $LINENO
+rm -f foo bar baz || framework_failure
 "${TARLZ}" -xf "${test3}" --missing-crc || test_failed $LINENO
 cmp cfoo foo || test_failed $LINENO
 cmp cbar bar || test_failed $LINENO
 cmp cbaz baz || test_failed $LINENO
 rm -f foo bar baz || framework_failure
+"${TARLZ}" -q -xf "${test3dot_lz}" --missing-crc || test_failed $LINENO
+cmp cfoo foo || test_failed $LINENO
+cmp cbar bar || test_failed $LINENO
+cmp cbaz baz || test_failed $LINENO
+rm -f foo bar baz || framework_failure
+"${TARLZ}" -q -xf "${test3dot_lz}" foo bar baz || test_failed $LINENO
+cmp cfoo foo || test_failed $LINENO
+cmp cbar bar || test_failed $LINENO
+cmp cbaz baz || test_failed $LINENO
+rm -f foo bar baz || framework_failure
 "${TARLZ}" -q -xf "${test3dir_lz}" --missing-crc || test_failed $LINENO
 cmp cfoo dir/foo || test_failed $LINENO
 cmp cbar dir/bar || test_failed $LINENO
 cmp cbaz dir/baz || test_failed $LINENO
 rm -rf dir || framework_failure
+"${TARLZ}" -q -xf "${test3dir_lz}" dir/foo dir/bar dir/baz || test_failed $LINENO
+cmp cfoo dir/foo || test_failed $LINENO
+cmp cbar dir/bar || test_failed $LINENO
+cmp cbaz dir/baz || test_failed $LINENO
+rm -rf dir || framework_failure
 
 # test --concatenate
 cat "${in_tar_lz}" > out.tar.lz || framework_failure
@@ -257,45 +280,43 @@ cmp out.tar.lz aout.tar.lz || test_failed $LINENO
 cat "${eof_lz}" > aout.tar.lz || framework_failure	# append to empty archive
 "${TARLZ}" -0 -rf aout.tar.lz foo bar baz || test_failed $LINENO
 cmp out.tar.lz aout.tar.lz || test_failed $LINENO
-mv -f foo foo.orig || framework_failure
-mv -f bar bar.orig || framework_failure
-mv -f baz baz.orig || framework_failure
+rm -f foo bar baz || framework_failure
 "${TARLZ}" -xf out.tar.lz foo/ bar// baz/// || test_failed $LINENO
-cmp foo foo.orig || test_failed $LINENO
-cmp bar bar.orig || test_failed $LINENO
-cmp baz baz.orig || test_failed $LINENO
+cmp cfoo foo || test_failed $LINENO
+cmp cbar bar || test_failed $LINENO
+cmp cbaz baz || test_failed $LINENO
 rm -f foo bar baz || framework_failure
 "${TARLZ}" -xf out.tar.lz || test_failed $LINENO
-cmp foo foo.orig || test_failed $LINENO
-cmp bar bar.orig || test_failed $LINENO
-cmp baz baz.orig || test_failed $LINENO
+cmp cfoo foo || test_failed $LINENO
+cmp cbar bar || test_failed $LINENO
+cmp cbaz baz || test_failed $LINENO
 mkdir dir1 || framework_failure
 "${TARLZ}" -C dir1 -xf out.tar.lz || test_failed $LINENO
-cmp dir1/foo foo.orig || test_failed $LINENO
-cmp dir1/bar bar.orig || test_failed $LINENO
-cmp dir1/baz baz.orig || test_failed $LINENO
+cmp cfoo dir1/foo || test_failed $LINENO
+cmp cbar dir1/bar || test_failed $LINENO
+cmp cbaz dir1/baz || test_failed $LINENO
 rm -f aout.tar.lz foo bar baz || framework_failure
 "${TARLZ}" -C dir1 -0 -cf aout.tar.lz foo bar baz || test_failed $LINENO
 "${TARLZ}" -xf aout.tar.lz || test_failed $LINENO
-cmp foo foo.orig || test_failed $LINENO
-cmp bar bar.orig || test_failed $LINENO
-cmp baz baz.orig || test_failed $LINENO
+cmp cfoo foo || test_failed $LINENO
+cmp cbar bar || test_failed $LINENO
+cmp cbaz baz || test_failed $LINENO
 rm -f aout.tar.lz foo bar baz || framework_failure
 "${TARLZ}" -C dir1 -0 -c foo bar baz | "${TARLZ}" -x || test_failed $LINENO
-cmp foo foo.orig || test_failed $LINENO
-cmp bar bar.orig || test_failed $LINENO
-cmp baz baz.orig || test_failed $LINENO
+cmp cfoo foo || test_failed $LINENO
+cmp cbar bar || test_failed $LINENO
+cmp cbaz baz || test_failed $LINENO
 rm -f dir1/foo dir1/bar dir1/baz || framework_failure
 "${TARLZ}" -0 -c foo bar baz | "${TARLZ}" -C dir1 -x || test_failed $LINENO
-cmp dir1/foo foo.orig || test_failed $LINENO
-cmp dir1/bar bar.orig || test_failed $LINENO
-cmp dir1/baz baz.orig || test_failed $LINENO
+cmp cfoo dir1/foo || test_failed $LINENO
+cmp cbar dir1/bar || test_failed $LINENO
+cmp cbaz dir1/baz || test_failed $LINENO
 rm -f dir1/foo dir1/bar dir1/baz || framework_failure
 "${TARLZ}" -0 -c foo bar baz | "${TARLZ}" -x foo bar baz -C dir1 ||
 	test_failed $LINENO
-cmp dir1/foo foo.orig || test_failed $LINENO
-cmp dir1/bar bar.orig || test_failed $LINENO
-cmp dir1/baz baz.orig || test_failed $LINENO
+cmp cfoo dir1/foo || test_failed $LINENO
+cmp cbar dir1/bar || test_failed $LINENO
+cmp cbaz dir1/baz || test_failed $LINENO
 rm -f foo dir1/bar baz || framework_failure
 "${TARLZ}" -0 -cf aout.tar.lz -C dir1 foo -C .. bar -C dir1 baz ||
 	test_failed $LINENO
@@ -303,8 +324,8 @@ cmp out.tar.lz aout.tar.lz || test_failed $LINENO
 "${TARLZ}" -0 -cf aout.tar.lz dir1/foo dir1/baz || test_failed $LINENO
 rm -rf dir1 || framework_failure
 "${TARLZ}" -xf aout.tar.lz dir1 || test_failed $LINENO
-cmp dir1/foo foo.orig || test_failed $LINENO
-cmp dir1/baz baz.orig || test_failed $LINENO
+cmp cfoo dir1/foo || test_failed $LINENO
+cmp cbaz dir1/baz || test_failed $LINENO
 rm -rf dir1 || framework_failure
 rm -f out.tar.lz aout.tar.lz || framework_failure
 
@@ -328,13 +349,13 @@ for i in --asolid --dsolid -0 ; do
 			test_failed $LINENO "$i $j"
 		rm -f foo bar baz || framework_failure
 		"${TARLZ}" -xf out.tar.lz || test_failed $LINENO "$i $j"
-		cmp foo foo.orig || test_failed $LINENO "$i $j"
-		cmp bar bar.orig || test_failed $LINENO "$i $j"
-		cmp baz baz.orig || test_failed $LINENO "$i $j"
+		cmp cfoo foo || test_failed $LINENO "$i $j"
+		cmp cbar bar || test_failed $LINENO "$i $j"
+		cmp cbaz baz || test_failed $LINENO "$i $j"
 		rm -f out.tar.lz || framework_failure
 	done
 done
-rm -f foo foo.orig bar bar.orig baz baz.orig || framework_failure
+rm -f foo bar baz || framework_failure
 
 # test directories and links
 mkdir dir1 || framework_failure
@@ -405,6 +426,19 @@ if [ "${ln_works}" = yes ] ; then
 	rm -rf dir2 dir1 || framework_failure
 fi
 
+"${TARLZ}" -tvf "${testdir}"/ug32chars.tar.lz | grep -q \
+	-e very_long_owner_name_of_32_chars/very_long_group_name_of_32_chars ||
+	test_failed $LINENO
+"${TARLZ}" -tvf "${testdir}"/ug32chars.tar.lz | grep -q \
+	-e very_long_owner_name_of_32_charsvery_long_group_name_of_32_chars &&
+	test_failed $LINENO
+"${TARLZ}" -tvf "${testdir}"/ug32chars.tar.lz | grep -q \
+	-e very_long_group_name_of_32_chars/very_long_group_name_of_32_chars &&
+	test_failed $LINENO
+"${TARLZ}" -xf "${testdir}"/ug32chars.tar.lz || test_failed $LINENO
+cmp cfoo foo || test_failed $LINENO
+rm -f foo || framework_failure
+
 printf "\ntesting bad input..."
 
 "${TARLZ}" -q -xf "${testdir}"/dotdot1.tar.lz || test_failed $LINENO
